parse

package
v0.0.0-...-d72b88c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 2, 2019 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Issue

func Issue(line string, headers []string) (i charlie.Issue)

Issue method parses issue string with headers data

func ReactChangelog

func ReactChangelog(_, data string) ([]charlie.Release, error)

ReactChangelog Parses react change logs

func SpringChangeLogFileURL

func SpringChangeLogFileURL(projectName string) string

SpringChangeLogFileURL builds url for spring project changelog file

func SpringChangelog

func SpringChangelog(_, data string) ([]charlie.Release, error)

SpringChangelog parses Spring framework changelog

func Trim

func Trim(line string) string

Trim method removes trailing and leading spaces Also this method joins two or more consecutive spaces into one

func Version

func Version(src string) (*charlie.Version, bool)

Version parses release signature from string

Types

This section is empty.

Directories

Path Synopsis

Jump to