Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SimpleListLine ¶
type SimpleListLine struct {
Index int // Contains line number
Value string // Contains line contents
Headers []string // Contains headers
}
SimpleListLine contains information about exactly one line from Markdown document with type list (<ol> or <ul>)
func ToListLines ¶
func ToListLines(src string) []SimpleListLine
ToListLines parses Markdown document and returns list of lines
func (SimpleListLine) String ¶
func (s SimpleListLine) String() string
String returns line value without Markdown prefix This is also Stringer interface implementation
Click to show internal directories.
Click to hide internal directories.